@@ -52,7 +52,9 @@ gog_dataset_get_type (void)
  * @first : inclusive
  * @last : _inclusive_
  *
- * Returns the first and last valid indicises to get/set dim.
+ * FIXME ?? Fix what ??
+ * Stores the first and last valid indicises to get/set dim
+ * in @first and @last.
  **/
 void
 gog_dataset_dims (GogDataset const *set, int *first, int *last)
@@ -61,7 +63,7 @@ gog_dataset_dims (GogDataset const *set, int *first, int *last)
 	g_return_if_fail (klass != NULL);
 	g_return_if_fail (first != NULL);
 	g_return_if_fail (last != NULL);
-	return (klass->dims) (set, first, last);
+	(klass->dims) (set, first, last);
 }
 
 /**
@@ -69,8 +71,8 @@ gog_dataset_dims (GogDataset const *set, int *first, int *last)
  * @set : #GogDataset
  * @dim_i :
  *
- * Returns the GOData associated with dimension @dim_i.  Does NOT add a
- * reference.
+ * Returns: the GOData associated with dimension @dim_i.  Does NOT add a
+ * 	reference.
  **/
 GOData *
 gog_dataset_get_dim (GogDataset const *set, int dim_i)
@@ -82,10 +84,10 @@ gog_dataset_get_dim (GogDataset const *set, int dim_i)
 
 /**
  * gog_dataset_set_dim :
- * @series : #GogSeries
- * @dim_i :  < 0 gets the name
- * @val : #GOData
- * @err : #GError
+ * @set: #GogDataset
+ * @dim_i:  < 0 gets the name
+ * @val: #GOData
+ * @err: #GError
  *
  * Absorbs a ref to @val if it is non NULL
  **/
@@ -94,7 +96,7 @@ gog_dataset_set_dim (GogDataset *set, int dim_i, GOData *val, GError **err)
 {
 	GogDatasetClass *klass;
 
-	g_return_if_fail (val == NULL || GO_DATA (val) != NULL);
+	g_return_if_fail (val == NULL || IS_GO_DATA (val));
 
 	if (set == NULL || !IS_GOG_DATASET (set)) {
 		g_warning ("gog_dataset_set_dim called with invalid GogDataset");
