@@ -22,7 +22,12 @@
 #define GOG_GRAPH_H
 
 #include <goffice/graph/goffice-graph.h>
+#include <goffice/graph/gog-view.h>
 #include <goffice/data/goffice-data.h>
+#include <goffice/utils/go-image.h>
+
+#include <gsf/gsf.h>
+
 #include <glib-object.h>
 
 G_BEGIN_DECLS
@@ -32,7 +37,6 @@ G_BEGIN_DECLS
 #define IS_GOG_GRAPH(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_GRAPH_TYPE))
 
 GType gog_graph_get_type (void);
-GType gog_graph_view_get_type (void);
 
 gboolean  gog_graph_validate_chart_layout (GogGraph *graph);
 unsigned  gog_graph_num_cols	  (GogGraph const *graph);
@@ -52,7 +56,29 @@ void      gog_graph_unref_data    (GogGraph *graph, GOData *dat);
 
 void	  gog_graph_get_size 	  (GogGraph *graph, double *width, double *height);
 void      gog_graph_set_size      (GogGraph *graph, double width, double height);
-	
+
+#define GOG_GRAPH_VIEW_TYPE	(gog_graph_view_get_type ())
+#define GOG_GRAPH_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_GRAPH_VIEW_TYPE, GogGraphView))
+#define IS_GOG_GRAPH_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_GRAPH_VIEW_TYPE))
+
+GType gog_graph_view_get_type (void);
+
+GogView *gog_graph_view_get_selection 	(GogGraphView *gview);
+void 	 gog_graph_view_set_selection   (GogGraphView *gview, GogObject *gobj);
+
+
+GSList 	 *gog_graph_get_supported_image_formats	(void);
+gboolean  gog_graph_export_image 		(GogGraph *graph, GOImageFormat format, 
+						 GsfOutput *output, double x_dpi, double y_dpi);
+
+#ifdef GOFFICE_WITH_GTK
+#include <goffice/gtk/goffice-gtk.h>
+void  	 gog_graph_view_handle_event 	(GogGraphView *gview, GdkEvent *event, double x_offset, double y_offset);
+#endif
+
+void gog_graph_render_to_cairo 		(GogGraph *graph, gpointer data, double w, double h);
+void gog_graph_render_to_cairo_vector 	(GogGraph *graph, gpointer data, double w, double h);
+
 G_END_DECLS
 
 #endif /* GOG_GRAPH_H */
