@@ -45,6 +45,8 @@
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-output-stdio.h>
 
+#include <glib/gi18n-lib.h>
+
 #include <cairo.h>
 #ifdef CAIRO_HAS_PDF_SURFACE
 #include <cairo-pdf.h>
@@ -156,69 +158,70 @@ grc_free_marker_data (GogRendererCairo *crend)
 	}
 }
 
+#define GRC_LINEAR_SCALE(w,scale) (go_sub_epsilon (w) <= 0.0 ? GOG_RENDERER_HAIRLINE_WIDTH_PTS : w) * scale 
+
 static double
-grc_line_size (GogRenderer const *rend, double width)
+grc_line_size (GogRenderer const *rend, double width, gboolean sharp)
 {
 	GogRendererCairo *crend = GOG_RENDERER_CAIRO (rend);
 
 	if (crend->is_vector)
-		return go_sub_epsilon (width) <= 0. ?
-			GOG_RENDERER_HAIR_LINE_WIDTH :
-			width * rend->scale;
+		return GRC_LINEAR_SCALE (width, rend->scale);
 
 	if (go_sub_epsilon (width) <= 0.) /* cheesy version of hairline */
 		return 1.;
 	
 	width *= rend->scale;
-	if (width <= 1.)
+	if (!sharp || width <= 1.)
 		return width;
 
-	return floor (width);
+	return go_fake_round (width);
 }
 
 /* This is a workaround for a cairo bug, due to its internal
  * handling of coordinates (16.16 fixed point). */
 #define GO_CAIRO_CLAMP(x) CLAMP((x),-15000,15000)
+#define GO_CAIRO_CLAMP_SNAP(x,even) GO_CAIRO_CLAMP(even ? floor (x + .5):floor (x) + .5)
 
 static void
-grc_path (cairo_t *cr, ArtVpath *vpath, ArtBpath *bpath)
+grc_path_raw (cairo_t *cr, ArtVpath *vpath, ArtBpath *bpath)
 {
-	if (vpath) 
+	if (vpath) { 
 		while (vpath->code != ART_END) {
 			switch (vpath->code) {
 				case ART_MOVETO_OPEN:
 				case ART_MOVETO:
 					cairo_move_to (cr, GO_CAIRO_CLAMP (vpath->x), 
-						           GO_CAIRO_CLAMP (vpath->y));
+						       GO_CAIRO_CLAMP (vpath->y));
 					break;
 				case ART_LINETO:
 					cairo_line_to (cr, GO_CAIRO_CLAMP (vpath->x), 
-						           GO_CAIRO_CLAMP (vpath->y));
+						       GO_CAIRO_CLAMP (vpath->y));
 					break;
 				default:
 					break;
 			}
 			vpath++;
 		}
-	else
+	} else
 		while (bpath->code != ART_END) {
 			switch (bpath->code) {
 				case ART_MOVETO_OPEN:
 				case ART_MOVETO:
 					cairo_move_to (cr, GO_CAIRO_CLAMP (bpath->x3),
-						      	   GO_CAIRO_CLAMP (bpath->y3));
+						       GO_CAIRO_CLAMP (bpath->y3));
 					break;
 				case ART_LINETO:
 					cairo_line_to (cr, GO_CAIRO_CLAMP (bpath->x3),
-						           GO_CAIRO_CLAMP (bpath->y3));
+						       GO_CAIRO_CLAMP (bpath->y3));
 					break;
 				case ART_CURVETO:
 					cairo_curve_to (cr, GO_CAIRO_CLAMP (bpath->x1), 
-							    GO_CAIRO_CLAMP (bpath->y1),
-							    GO_CAIRO_CLAMP (bpath->x2), 
-							    GO_CAIRO_CLAMP (bpath->y2),
-							    GO_CAIRO_CLAMP (bpath->x3), 
-							    GO_CAIRO_CLAMP (bpath->y3));
+							GO_CAIRO_CLAMP (bpath->y1),
+							GO_CAIRO_CLAMP (bpath->x2), 
+							GO_CAIRO_CLAMP (bpath->y2),
+							GO_CAIRO_CLAMP (bpath->x3), 
+							GO_CAIRO_CLAMP (bpath->y3));
 					break;
 				default:
 					break;
@@ -228,18 +231,62 @@ grc_path (cairo_t *cr, ArtVpath *vpath, ArtBpath *bpath)
 }
 
 static void
-grc_draw_path (GogRenderer *rend, ArtVpath const *vpath, ArtBpath const*bpath)
+grc_path_sharp (cairo_t *cr, ArtVpath *vpath, ArtBpath *bpath, double line_width)
+{
+	gboolean even = ((int) (go_fake_ceil (line_width)) % 2 == 0) && line_width > 1.0;
+
+	if (vpath) 
+		while (vpath->code != ART_END) {
+			switch (vpath->code) {
+				case ART_MOVETO_OPEN:
+				case ART_MOVETO:
+					cairo_move_to (cr, GO_CAIRO_CLAMP_SNAP (vpath->x, even), 
+						           GO_CAIRO_CLAMP_SNAP (vpath->y, even));
+					break;
+				case ART_LINETO:
+					cairo_line_to (cr, GO_CAIRO_CLAMP_SNAP (vpath->x, even), 
+						           GO_CAIRO_CLAMP_SNAP (vpath->y, even));
+					break;
+				default:
+					break;
+			}
+			vpath++;
+		}
+}
+
+static void
+grc_path (cairo_t *cr, ArtVpath *vpath, ArtBpath *bpath, double line_width, gboolean sharp)
+{
+	if (sharp)
+		grc_path_sharp (cr, vpath, bpath, line_width);
+	else
+		grc_path_raw (cr, vpath, bpath);
+}
+
+static void
+grc_draw_path (GogRenderer *rend, ArtVpath const *vpath, ArtBpath const*bpath, gboolean sharp)
 {
 	GogRendererCairo *crend = GOG_RENDERER_CAIRO (rend);
 	GogStyle const *style = rend->cur_style;
 	cairo_t *cr = crend->cairo;
-	double width = grc_line_size (rend, style->line.width);
+	double width;
+	gboolean legend_line;
 
 	g_return_if_fail (bpath != NULL || vpath != NULL);
 
 	if (style->line.dash_type == GO_LINE_NONE)
 		return;
 
+	/* KLUDGE snap coordinate of legend line sample. */
+	legend_line =!sharp 
+		&& !crend->is_vector
+		&& vpath != NULL 
+		&& vpath[0].code == ART_MOVETO 
+		&& vpath[1].code == ART_LINETO 
+		&& vpath[2].code == ART_END 
+		&& (vpath[0].x == vpath[1].x || vpath[0].y == vpath[1].y);
+
+	width = grc_line_size (rend, style->line.width, sharp);
 	cairo_set_line_width (cr, width);
 	if (rend->line_dash != NULL)
 		cairo_set_dash (cr, 
@@ -248,8 +295,12 @@ grc_draw_path (GogRenderer *rend, ArtVpath const *vpath, ArtBpath const*bpath)
 				rend->line_dash->offset);
 	else
 		cairo_set_dash (cr, NULL, 0, 0);
-	grc_path (cr, (ArtVpath *) vpath, (ArtBpath *) bpath);
+
+	grc_path (cr, (ArtVpath *) vpath, (ArtBpath *) bpath, width, 
+		  (sharp || legend_line) && !crend->is_vector);
 	cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (style->line.color));
+	cairo_set_line_cap (cr, (width <= 2.0 && !crend->is_vector) ? 
+			    CAIRO_LINE_CAP_SQUARE : CAIRO_LINE_CAP_ROUND);
 	cairo_stroke (cr);
 }
 
@@ -279,13 +330,13 @@ gog_renderer_cairo_push_clip (GogRenderer *rend, GogRendererClip *clip)
 
 	cairo_save (crend->cairo);
 	if (is_rectangle) {
-		double x = floor (path[0].x + 0.5);
-		double y = floor (path[0].y + 0.5);
+		double x = go_fake_floor (path[0].x);
+		double y = go_fake_floor (path[0].y);
 		cairo_rectangle (crend->cairo, x, y,
-				 floor (path[1].x + 0.5) - x,
-				 floor (path[2].y + 0.5) - y);
+				 go_fake_ceil (path[1].x) - x,
+				 go_fake_ceil (path[2].y) - y);
 	} else {
-		grc_path (crend->cairo, path, NULL);
+		grc_path (crend->cairo, path, NULL, 0.0, FALSE);
 	}
 	cairo_clip (crend->cairo);
 }
@@ -299,10 +350,10 @@ gog_renderer_cairo_pop_clip (GogRenderer *rend, GogRendererClip *clip)
 }
 
 static double
-gog_renderer_cairo_line_size (GogRenderer const *rend, double width)
+gog_renderer_cairo_line_size (GogRenderer const *rend, double width, gboolean sharp)
 {
 	GogRendererCairo *crend = GOG_RENDERER_CAIRO (rend);
-	double size = grc_line_size (rend, width);
+	double size = grc_line_size (rend, width, sharp);
 
 	if (!crend->is_vector && size < 1.0)
 		return ceil (size);
@@ -310,44 +361,33 @@ gog_renderer_cairo_line_size (GogRenderer const *rend, double width)
 	return size;
 }
 
-static void
-gog_renderer_cairo_sharp_path (GogRenderer *rend, ArtVpath *path, double line_width) 
+static double
+gog_renderer_cairo_hairline_pts (GogRenderer const *rend)
 {
 	GogRendererCairo *crend = GOG_RENDERER_CAIRO (rend);
-	ArtVpath *iter = path;
 
-	if (crend->is_vector)
-		return;
+	if (crend->is_vector
+	    || go_sub_epsilon (rend->scale) <= 0.0)
+	       return GOG_RENDERER_HAIRLINE_WIDTH_PTS;
 
-	if (((int) (rint (line_width)) % 2 == 0) && line_width > 1.0) 
-		while (iter->code != ART_END) {
-			iter->x = floor (iter->x + .5);
-			iter->y = floor (iter->y + .5);
-			iter++;
-		}
-	else
-		while (iter->code != ART_END) {
-			iter->x = floor (iter->x) + .5;
-			iter->y = floor (iter->y) + .5;
-			iter++;
-		}
+	return 1.0 / rend->scale;
 }
 
 static void
-gog_renderer_cairo_draw_path (GogRenderer *rend, ArtVpath const *path)
+gog_renderer_cairo_draw_path (GogRenderer *rend, ArtVpath const *path, gboolean sharp)
 {
-	grc_draw_path (rend, path, NULL);
+	grc_draw_path (rend, path, NULL, sharp);
 }
   
 static void
 gog_renderer_cairo_draw_bezier_path (GogRenderer *rend, ArtBpath const *path)
 {
-	grc_draw_path (rend, NULL, path);
+	grc_draw_path (rend, NULL, path, FALSE);
 }
 
 static void
-grc_draw_polygon (GogRenderer *rend, ArtVpath const *vpath, 
-		  ArtBpath const *bpath, gboolean narrow)
+grc_draw_polygon (GogRenderer *rend, ArtVpath const *vpath, ArtBpath const *bpath, 
+		  gboolean sharp, gboolean narrow)
 {
 	struct { unsigned x0i, y0i, x1i, y1i; } const grad_i[GO_GRADIENT_MAX] = {
 		{0, 0, 0, 1},
@@ -377,7 +417,7 @@ grc_draw_polygon (GogRenderer *rend, ArtVpath const *vpath,
 	GdkPixbuf *pixbuf = NULL;
 	GOImage *image = NULL;
 	GOColor color;
-	double width = grc_line_size (rend, style->outline.width);
+	double width = grc_line_size (rend, style->outline.width, sharp);
 	double x[3], y[3];
 	int i, j, w, h;
 	guint8 const *pattern;
@@ -391,7 +431,8 @@ grc_draw_polygon (GogRenderer *rend, ArtVpath const *vpath,
 		return;
 
 	cairo_set_line_width (cr, width);
-	grc_path (cr, (ArtVpath *) vpath, (ArtBpath *) bpath);
+	grc_path (cr, (ArtVpath *) vpath, (ArtBpath *) bpath, width, 
+		  sharp && !crend->is_vector);
 
 	switch (style->fill.type) {
 		case GOG_FILL_STYLE_PATTERN:
@@ -491,6 +532,8 @@ grc_draw_polygon (GogRenderer *rend, ArtVpath const *vpath,
 					rend->outline_dash->offset);
 		else
 			cairo_set_dash (cr, NULL, 0, 0);
+		cairo_set_line_cap (cr, (width < 3 && !crend->is_vector) ? 
+				    CAIRO_LINE_CAP_SQUARE : CAIRO_LINE_CAP_ROUND);
 		cairo_stroke (cr);
 	}
 
@@ -505,17 +548,17 @@ grc_draw_polygon (GogRenderer *rend, ArtVpath const *vpath,
 }
 
 static void
-gog_renderer_cairo_draw_polygon (GogRenderer *rend, ArtVpath const *path, 
+gog_renderer_cairo_draw_polygon (GogRenderer *rend, ArtVpath const *path, gboolean sharp, 
 				 gboolean narrow)
 {
-	grc_draw_polygon (rend, path, NULL, narrow);
+	grc_draw_polygon (rend, path, NULL, sharp, narrow);
 }
 
 static void
 gog_renderer_cairo_draw_bezier_polygon (GogRenderer *rend, ArtBpath const *path,
 					 gboolean narrow)
 {
-	grc_draw_polygon (rend, NULL, path, narrow);
+	grc_draw_polygon (rend, NULL, path, FALSE, narrow);
 }
 
 static void
@@ -544,7 +587,7 @@ gog_renderer_cairo_draw_text (GogRenderer *rend, char const *text,
 
 	obr.w = rend->scale * (iw / (double)PANGO_SCALE);
 	obr.h = rend->scale * (ih / (double)PANGO_SCALE);
-	obr.alpha = style->text_layout.angle * M_PI / 180.0;
+	obr.alpha = -style->text_layout.angle * M_PI / 180.0;
 	obr.x = pos->x;
 	obr.y = pos->y;
 	go_geometry_OBR_to_AABR (&obr, &aabr);
@@ -571,9 +614,9 @@ gog_renderer_cairo_draw_text (GogRenderer *rend, char const *text,
 
 	cairo_save (cairo);
 	cairo_set_source_rgba (cairo, GO_COLOR_TO_CAIRO (style->font.color)); 
-	cairo_move_to (cairo, obr.x - (obr.w / 2.0) * cos (obr.alpha) - (obr.h / 2.0) * sin (obr.alpha),
-		       obr.y + (obr.w / 2.0) * sin (obr.alpha) - (obr.h / 2.0) * cos (obr.alpha));
-	cairo_rotate (cairo, -obr.alpha);
+	cairo_move_to (cairo, obr.x - (obr.w / 2.0) * cos (obr.alpha) + (obr.h / 2.0) * sin (obr.alpha),
+		       obr.y - (obr.w / 2.0) * sin (obr.alpha) - (obr.h / 2.0) * cos (obr.alpha));
+	cairo_rotate (cairo, obr.alpha);
 	cairo_scale (cairo, rend->scale, rend->scale);
 	pango_cairo_show_layout (cairo, layout);
 	cairo_restore (cairo);
@@ -632,14 +675,14 @@ grc_draw_marker (cairo_t *cairo, GOMarker *marker, double x, double y, double sc
 
 	path = art_vpath_affine_transform (fill_path_raw, affine);
 	cairo_set_source_rgba (cairo, GO_COLOR_TO_CAIRO (go_marker_get_fill_color (marker)));
-	grc_path (cairo, path, NULL);
+	grc_path (cairo, path, NULL, 0.0, FALSE);
 	cairo_fill (cairo);
 	art_free (path);
 
 	path = art_vpath_affine_transform (outline_path_raw, affine);
 	cairo_set_source_rgba (cairo, GO_COLOR_TO_CAIRO (go_marker_get_outline_color (marker)));
 	cairo_set_line_width (cairo, scale * go_marker_get_outline_width (marker));
-	grc_path (cairo, path, NULL);
+	grc_path (cairo, path, NULL, 0.0, FALSE);
 	cairo_stroke (cairo);
 	art_free (path);
 }
@@ -892,7 +935,6 @@ gog_renderer_cairo_class_init (GogRendererClass *rend_klass)
 	rend_klass->pop_style		= gog_renderer_cairo_pop_style;
 	rend_klass->push_clip  		= gog_renderer_cairo_push_clip;
 	rend_klass->pop_clip     	= gog_renderer_cairo_pop_clip;
-	rend_klass->sharp_path		= gog_renderer_cairo_sharp_path;
 	rend_klass->draw_path	  	= gog_renderer_cairo_draw_path;
 	rend_klass->draw_polygon  	= gog_renderer_cairo_draw_polygon;
 	rend_klass->draw_bezier_path 	= gog_renderer_cairo_draw_bezier_path;
@@ -901,16 +943,20 @@ gog_renderer_cairo_class_init (GogRendererClass *rend_klass)
 	rend_klass->draw_marker	  	= gog_renderer_cairo_draw_marker;
 	rend_klass->get_text_OBR	= gog_renderer_cairo_get_text_OBR;
 	rend_klass->line_size		= gog_renderer_cairo_line_size;
+	rend_klass->hairline_pts 	= gog_renderer_cairo_hairline_pts;
 	rend_klass->export_image	= gog_renderer_cairo_export_image;
 
 	g_object_class_install_property (gobject_klass, RENDERER_CAIRO_PROP_CAIRO,
-		g_param_spec_pointer ("cairo", "cairo",
-			"the cairo_t* this renderer uses",
-			G_PARAM_READWRITE));
+		g_param_spec_pointer ("cairo", 
+			_("Cairo"),
+			_("The cairo_t* this renderer uses"),
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_klass, RENDERER_CAIRO_PROP_IS_VECTOR,
-		g_param_spec_boolean ("is-vector", "is-vector",
-			"tells if the cairo surface is vectorial or raster", FALSE,
-			G_PARAM_READWRITE));
+		g_param_spec_boolean ("is-vector",
+			_("Is vector"),
+			_("Tells if the cairo surface is vectorial or raster"),
+		       	FALSE,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 }
 
 static void
@@ -934,7 +980,7 @@ GSF_CLASS (GogRendererCairo, gog_renderer_cairo,
  * @h:
  * @zoom:
  *
- * Returns TRUE if the size actually changed.
+ * Returns: TRUE if the size actually changed.
  **/
 gboolean
 gog_renderer_cairo_update (GogRendererCairo *crend, int w, int h, double zoom)
