@@ -93,10 +93,6 @@ struct _GogStyle {
 	GogStyleFlag	disable_theming;
 
 	GogStyleLine	outline, line;
-	struct {
-		GOLineInterpolation type;
-		gboolean 	 auto_type;
-	} interpolation;
 	struct {
 		GogFillStyle	type;
 		gboolean	auto_fore, auto_back;	/* share between pattern and gradient */
