@@ -44,7 +44,7 @@
 
 typedef struct {
 	GogPlotClass	base;
-	
+
 	void (*adjust_bounds) (Gog2DPlot *model, double *x_min, double *x_max, double *y_min, double *y_max);
 } Gog2DPlotClass;
 
@@ -52,6 +52,8 @@ typedef Gog2DPlotClass GogXYPlotClass;
 
 typedef Gog2DPlotClass GogBubblePlotClass;
 
+typedef Gog2DPlotClass GogXYColorPlotClass;
+
 GOFFICE_PLUGIN_MODULE_HEADER;
 
 static GogObjectClass *plot2d_parent_klass;
@@ -137,7 +139,7 @@ gog_2d_plot_update (GogObject *obj)
 		if (y_max < tmp_max)
 			y_max = tmp_max;
 	}
-	
+
 	if (model->x.minima != x_min || model->x.maxima != x_max) {
 		model->x.minima = x_min;
 		model->x.maxima = x_max;
@@ -186,8 +188,8 @@ gog_2d_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 			if (gog_series_is_valid (GOG_SERIES (ptr->data)))
 				return GOG_SERIES (ptr->data)->values[0].data;
 		return NULL;
-	} 
-	
+	}
+
 	if (axis == GOG_AXIS_Y) {
 		bounds->val.minima = model->y.minima;
 		bounds->val.maxima = model->y.maxima;
@@ -245,8 +247,7 @@ enum {
 	GOG_XY_PROP_0,
 	GOG_XY_PROP_DEFAULT_STYLE_HAS_MARKERS,
 	GOG_XY_PROP_DEFAULT_STYLE_HAS_LINES,
-	GOG_XY_PROP_USE_SPLINES,
-	GOG_XY_PROP_INTERPOLATION,
+	GOG_XY_PROP_USE_SPLINES
 };
 
 static GogObjectClass *xy_parent_klass;
@@ -271,19 +272,12 @@ gog_xy_set_property (GObject *obj, guint param_id,
 	case GOG_XY_PROP_DEFAULT_STYLE_HAS_MARKERS:
 		xy->default_style_has_markers = g_value_get_boolean (value);
 		break;
-	case GOG_XY_PROP_DEFAULT_STYLE_HAS_LINES: {
+	case GOG_XY_PROP_DEFAULT_STYLE_HAS_LINES:
 		xy->default_style_has_lines = g_value_get_boolean (value);
 		break;
-	}
 	case GOG_XY_PROP_USE_SPLINES:
-		if (g_value_get_boolean (value))
-			xy->interpolation = GO_LINE_INTERPOLATION_SPLINE;
+		xy->use_splines = g_value_get_boolean (value);
 		break;
-	case GOG_XY_PROP_INTERPOLATION: {
-		char const *s = g_value_get_string (value);
-		xy->interpolation = go_line_interpolation_from_str (s);;
-		break;
-	}
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
 	}
@@ -293,6 +287,10 @@ gog_xy_get_property (GObject *obj, guint param_id,
 		     GValue *value, GParamSpec *pspec)
 {
 	GogXYPlot const *xy = GOG_XY_PLOT (obj);
+	GogSeries *series;
+	GSList *iter;
+	gboolean use_splines;
+
 	switch (param_id) {
 	case GOG_XY_PROP_DEFAULT_STYLE_HAS_MARKERS:
 		g_value_set_boolean (value, xy->default_style_has_markers);
@@ -301,10 +299,14 @@ gog_xy_get_property (GObject *obj, guint param_id,
 		g_value_set_boolean (value, xy->default_style_has_lines);
 		break;
 	case GOG_XY_PROP_USE_SPLINES:
-		g_value_set_boolean (value, xy->interpolation == GO_LINE_INTERPOLATION_SPLINE);
-		break;
-	case GOG_XY_PROP_INTERPOLATION:
-		g_value_set_string (value, go_line_interpolation_as_str (xy->interpolation));
+		use_splines = xy->use_splines;
+		/* Drop use_splines as soon as one of the series has interpolation different
+		 * from GO_LINE_INTERPOLATION_SPLINE */
+		for (iter = GOG_PLOT (xy)->series; iter != NULL; iter = iter->next) {
+			series = iter->data;
+			use_splines = use_splines && (series->interpolation == GO_LINE_INTERPOLATION_SPLINE);
+		}
+		g_value_set_boolean (value, use_splines);
 		break;
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
@@ -323,21 +325,23 @@ gog_xy_plot_class_init (GogPlotClass *plot_klass)
 	gobject_klass->get_property = gog_xy_get_property;
 
 	g_object_class_install_property (gobject_klass, GOG_XY_PROP_DEFAULT_STYLE_HAS_MARKERS,
-		g_param_spec_boolean ("default-style-has-markers", NULL,
-			"Should the default style of a series include markers",
-			TRUE, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("default-style-has-markers", 
+			_("Default markers"),
+			_("Should the default style of a series include markers"),
+			TRUE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GOG_XY_PROP_DEFAULT_STYLE_HAS_LINES,
-		g_param_spec_boolean ("default-style-has-lines", NULL,
-			"Should the default style of a series include lines",
-			TRUE, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("default-style-has-lines", 
+			_("Default lines"),
+			_("Should the default style of a series include lines"),
+			TRUE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GOG_XY_PROP_USE_SPLINES,
-		g_param_spec_boolean ("use-splines", NULL,
-			"Should the plot use splines instead of linear interpolation",
-			FALSE, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
-	g_object_class_install_property (gobject_klass, GOG_XY_PROP_INTERPOLATION,
-		g_param_spec_string  ("interpolation", NULL,
-			_("Interpolation type (none, linear, spline or step) with variant, if any."),
-            "none", G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("use-splines",
+			_("Use splines"),
+			_("Should the plot use splines instead of linear interpolation"),
+			FALSE,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	gog_klass->type_name	= gog_xy_plot_type_name;
 
 	{
@@ -480,25 +484,29 @@ gog_bubble_plot_class_init (GogPlotClass *plot_klass)
 	gog_2d_plot_klass->adjust_bounds = gog_bubble_plot_adjust_bounds;
 
 	g_object_class_install_property (gobject_klass, GOG_BUBBLE_PROP_AS_AREA,
-		g_param_spec_boolean ("size-as-area", "size-as-area",
-			"Display size as area instead of diameter",
+		g_param_spec_boolean ("size-as-area", 
+			_("Size as area"),
+			_("Display size as area instead of diameter"),
 			TRUE,
-			G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GOG_BUBBLE_PROP_SHOW_NEGATIVES,
-		g_param_spec_boolean ("show-negatives", "show-negatives",
-			"Draw bubbles for negative values",
+		g_param_spec_boolean ("show-negatives", 
+			_("Show negatives"),
+			_("Draw bubbles for negative values"),
 			FALSE,
-			G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GOG_BUBBLE_PROP_IN_3D,
-		g_param_spec_boolean ("in-3d", "in-3d",
-			"Draw 3d bubbles",
+		g_param_spec_boolean ("in-3d", 
+			_("In 3d"),
+			_("Draw 3d bubbles"),
 			FALSE,
-			G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GOG_BUBBLE_PROP_SCALE,
-		g_param_spec_float ("bubble-scale", "bubble-scale",
-			"Fraction of default radius used for display.",
+		g_param_spec_float ("bubble-scale", 
+			_("Bubble scale"),
+			_("Fraction of default radius used for display"),
 			0., 2., 1.,
-			G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	{
 		static GogSeriesDimDesc dimensions[] = {
 			{ N_("X"), GOG_SERIES_SUGGESTED, FALSE,
@@ -551,6 +559,236 @@ GSF_DYNAMIC_CLASS (GogBubblePlot, gog_bubble_plot,
 	gog_bubble_plot_class_init, gog_bubble_plot_init,
 	GOG_2D_PLOT_TYPE)
 
+/*****************************************************************************/
+
+enum {
+	GOG_XY_COLOR_PROP_0,
+	GOG_XY_COLOR_PROP_DEFAULT_STYLE_HAS_LINES,
+	GOG_XY_COLOR_PROP_INTERPOLATION,
+	GOG_XY_COLOR_PROP_HIDE_OUTLIERS,
+};
+
+static GogObjectClass *map_parent_klass;
+
+#define GOG_XY_COLOR_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_XY_COLOR_PLOT_TYPE, GogXYColorPlotClass))
+
+static void
+gog_xy_color_plot_clear_formats (GogXYColorPlot *map)
+{
+	if (map->z.fmt != NULL) {
+		go_format_unref (map->z.fmt);
+		map->z.fmt = NULL;
+	}
+}
+
+static void
+gog_xy_color_plot_update (GogObject *obj)
+{
+	GogXYColorPlot *model = GOG_XY_COLOR_PLOT (obj);
+	GogXYSeries const *series = NULL;
+	double z_min, z_max, tmp_min, tmp_max;
+	GSList *ptr;
+
+	z_min = DBL_MAX;
+	z_max = -DBL_MAX;
+	gog_xy_color_plot_clear_formats (model);
+	for (ptr = model->base.base.series ; ptr != NULL ; ptr = ptr->next) {
+		series = ptr->data;
+		if (!gog_series_is_valid (GOG_SERIES (series)))
+			continue;
+
+		go_data_vector_get_minmax (GO_DATA_VECTOR (
+			series->base.values[2].data), &tmp_min, &tmp_max);
+		if (z_min > tmp_min) z_min = tmp_min;
+		if (z_max < tmp_max) z_max = tmp_max;
+		if (model->z.fmt == NULL)
+			model->z.fmt = go_data_preferred_fmt (series->base.values[2].data);
+	}
+	if (model->z.minima != z_min || model->z.maxima != z_max) {
+		model->z.minima = z_min;
+		model->z.maxima = z_max;
+		gog_axis_bound_changed (model->base.base.axis[GOG_AXIS_COLOR], GOG_OBJECT (model));
+	}
+	map_parent_klass->update (obj);
+}
+
+static GOData *
+gog_xy_color_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
+			     GogPlotBoundInfo *bounds)
+{
+	if (axis == GOG_AXIS_COLOR) {
+		GogXYColorPlot *model = GOG_XY_COLOR_PLOT (plot);
+
+		bounds->val.minima = model->z.minima;
+		bounds->val.maxima = model->z.maxima;
+		bounds->is_discrete = model->z.minima > model->z.maxima ||
+			!go_finite (model->z.minima) ||
+			!go_finite (model->z.maxima);
+		if (bounds->fmt == NULL && model->z.fmt != NULL)
+			bounds->fmt = go_format_ref (model->z.fmt);
+		return NULL;
+	}
+	return GOG_PLOT_CLASS (map_parent_klass)->axis_get_bounds (plot, axis, bounds);
+}
+
+static char const *
+gog_xy_color_plot_type_name (G_GNUC_UNUSED GogObject const *item)
+{
+	/* xgettext : the base for how to name map like plot objects
+	 * eg The 2nd plot in a chart will be called
+	 * 	Map2 */
+	return N_("XYColor");
+}
+
+#ifdef GOFFICE_WITH_GTK
+#include <goffice/gtk/goffice-gtk.h>
+#include <gtk/gtktogglebutton.h>
+static void
+hide_outliers_toggled_cb (GtkToggleButton *btn, GObject *obj)
+{
+	g_object_set (obj, "hide-outliers", gtk_toggle_button_get_active (btn), NULL);
+}
+
+static void 
+gog_xy_color_plot_populate_editor (GogObject *obj,
+			       GogEditor *editor,
+			       GogDataAllocator *dalloc,
+			       GOCmdContext *cc)
+{
+	GtkWidget *w;
+	char const *dir = go_plugin_get_dir_name (
+		go_plugins_get_plugin_by_id ("GOffice_plot_xy"));
+	char *path = g_build_filename (dir, "gog-xy-color-prefs.glade", NULL);
+	GladeXML *gui = go_libglade_new (path, "gog-xy-color-prefs", GETTEXT_PACKAGE, cc);
+
+	g_free (path);
+
+	if (gui != NULL) {
+		w = glade_xml_get_widget (gui, "hide-outliers");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
+				(GOG_XY_COLOR_PLOT (obj))->hide_outliers);
+		g_signal_connect (G_OBJECT (w),
+			"toggled",
+			G_CALLBACK (hide_outliers_toggled_cb), obj);
+		w = glade_xml_get_widget (gui, "gog-xy-color-prefs");
+		gog_editor_add_page (editor, w, _("Properties"));
+	}
+
+	(GOG_OBJECT_CLASS(map_parent_klass)->populate_editor) (obj, editor, dalloc, cc);
+}
+#endif
+
+static void
+gog_xy_color_plot_set_property (GObject *obj, guint param_id,
+		     GValue const *value, GParamSpec *pspec)
+{
+	GogXYColorPlot *map = GOG_XY_COLOR_PLOT (obj);
+	switch (param_id) {
+	case GOG_XY_COLOR_PROP_DEFAULT_STYLE_HAS_LINES:
+		map->default_style_has_lines = g_value_get_boolean (value);
+		break;
+	case GOG_XY_COLOR_PROP_HIDE_OUTLIERS:
+		map->hide_outliers = g_value_get_boolean (value);
+		break;
+	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		 break;
+	}
+
+	/* none of the attributes triggers a size change yet.
+	 * When we add data labels we'll need it */
+	gog_object_emit_changed (GOG_OBJECT (obj), FALSE);
+}
+
+static void
+gog_xy_color_plot_get_property (GObject *obj, guint param_id,
+		     GValue *value, GParamSpec *pspec)
+{
+	GogXYColorPlot const *map = GOG_XY_COLOR_PLOT (obj);
+	switch (param_id) {
+	case GOG_XY_COLOR_PROP_DEFAULT_STYLE_HAS_LINES:
+		g_value_set_boolean (value, map->default_style_has_lines);
+		break;
+	case GOG_XY_COLOR_PROP_HIDE_OUTLIERS:
+		g_value_set_boolean (value, map->hide_outliers);
+		break;
+	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		 break;
+	}
+}
+
+static void
+gog_xy_color_plot_finalize (GObject *obj)
+{
+	gog_xy_color_plot_clear_formats (GOG_XY_COLOR_PLOT (obj));
+	G_OBJECT_CLASS (map_parent_klass)->finalize (obj);
+}
+
+static void
+gog_xy_color_plot_class_init (GogPlotClass *plot_klass)
+{
+	GObjectClass *gobject_klass = (GObjectClass *) plot_klass;
+	GogObjectClass *gog_klass = (GogObjectClass *) plot_klass;
+
+	map_parent_klass = g_type_class_peek_parent (plot_klass);
+
+	gobject_klass->set_property = gog_xy_color_plot_set_property;
+	gobject_klass->get_property = gog_xy_color_plot_get_property;
+	gobject_klass->finalize     = gog_xy_color_plot_finalize;
+
+	g_object_class_install_property (gobject_klass, GOG_XY_COLOR_PROP_DEFAULT_STYLE_HAS_LINES,
+		g_param_spec_boolean ("default-style-has-lines", 
+			_("Default lines"),
+			_("Should the default style of a series include lines"),
+			TRUE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, GOG_XY_COLOR_PROP_HIDE_OUTLIERS,
+		g_param_spec_boolean  ("hide-outliers", 
+			_("hide-outliers"),
+			_("Hide data outside of the color axis bounds"),
+			TRUE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+	gog_klass->type_name		= gog_xy_color_plot_type_name;
+	gog_klass->update		= gog_xy_color_plot_update;
+	gog_klass->populate_editor	= gog_xy_color_plot_populate_editor;
+	{
+		static GogSeriesDimDesc dimensions[] = {
+			{ N_("X"), GOG_SERIES_SUGGESTED, FALSE,
+			  GOG_DIM_INDEX, GOG_MS_DIM_CATEGORIES },
+			{ N_("Y"), GOG_SERIES_REQUIRED, FALSE,
+			  GOG_DIM_VALUE, GOG_MS_DIM_VALUES },
+			{ N_("Z"), GOG_SERIES_REQUIRED, FALSE,
+			  GOG_DIM_VALUE, GOG_MS_DIM_EXTRA1 },
+/* Names of the error data are not translated since they are not used */
+			{ "Y+err", GOG_SERIES_ERRORS, FALSE,
+			  GOG_DIM_VALUE, GOG_MS_DIM_ERR_plus1 },
+			{ "Y-err", GOG_SERIES_ERRORS, FALSE,
+			  GOG_DIM_VALUE, GOG_MS_DIM_ERR_minus1 },
+			{ "X+err", GOG_SERIES_ERRORS, FALSE,
+			  GOG_DIM_VALUE, GOG_MS_DIM_ERR_plus2 },
+			{ "X-err", GOG_SERIES_ERRORS, FALSE,
+			  GOG_DIM_VALUE, GOG_MS_DIM_ERR_minus2 }
+		};
+		plot_klass->desc.series.dim = dimensions;
+		plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
+		plot_klass->desc.series.style_fields = GOG_STYLE_LINE | GOG_STYLE_MARKER
+			| GOG_STYLE_INTERPOLATION |GOG_STYLE_MARKER_NO_COLOR;
+	}
+	plot_klass->axis_set	      	= GOG_AXIS_SET_XY_COLOR;
+	plot_klass->axis_get_bounds   	= gog_xy_color_plot_axis_get_bounds;
+}
+
+static void
+gog_xy_color_plot_init (GogXYColorPlot *map)
+{
+	map->default_style_has_lines = FALSE;
+	map->hide_outliers = TRUE;
+}
+
+GSF_DYNAMIC_CLASS (GogXYColorPlot, gog_xy_color_plot,
+	gog_xy_color_plot_class_init, gog_xy_color_plot_init,
+	GOG_2D_PLOT_TYPE)
+
+
 /*****************************************************************************/
 typedef GogPlotView		GogXYView;
 typedef GogPlotViewClass	GogXYViewClass;
@@ -578,8 +816,27 @@ bubble_draw_circle (GogView *view, double x, double y, double radius)
 	gog_renderer_draw_polygon (view->renderer, path, FALSE);
 }
 
+static GOColor
+get_map_color (double z, gboolean hide_outliers)
+{
+	if (hide_outliers && (z < 0. || z > 6.))
+		return 0;
+	if (z <= 0.)
+		return RGBA_BLUE;
+	if (z <= 1.)
+		return RGBA_BLUE + ((int) (z * 255.) << 16);
+	if (z <= 2.)
+		return RGBA_GREEN + ((int) ((2. - z) * 255) << 8);
+	if (z <= 4.)
+		return RGBA_GREEN + ((int) ((z / 2. - 1.) * 255) << 24);
+	if (z <= 6.)
+		return RGBA_RED + ((int) ((3. - z / 2.) * 255) << 16);
+	return RGBA_RED;
+}
+
 typedef struct {
 	double x, y;
+	GOColor color;
 } MarkerData;
 
 static void
@@ -589,7 +846,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 	unsigned num_series;
 	GogChart *chart = GOG_CHART (view->model->parent);
 	GogChartMap *chart_map;
-	GogAxisMap *x_map, *y_map;
+	GogAxisMap *x_map, *y_map, *z_map;
 	GogXYSeries const *series = NULL;
 	unsigned i ,j ,k ,n, tmp;
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (model));
@@ -597,12 +854,13 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 	GogViewAllocation const *area;
 	GSList *ptr;
 	double const *y_vals, *x_vals = NULL, *z_vals = NULL;
-	double x = 0., y = 0., z, x_canvas = 0., y_canvas = 0.;
+	double x = 0., y = 0., z = 0., x_canvas = 0., y_canvas = 0.;
 	double zmax, rmax = 0., x_zero, y_zero;
 	double x_margin_min, x_margin_max, y_margin_min, y_margin_max, margin;
 	double xerrmin, xerrmax, yerrmin, yerrmax;
 	GogStyle *style = NULL;
 	gboolean show_marks, show_lines, show_negatives, in_3d, size_as_area = TRUE;
+	gboolean is_map = GOG_IS_XY_COLOR_PLOT (model), hide_outliers = TRUE;
 
 	MarkerData **markers;
 	unsigned *num_markers;
@@ -619,6 +877,11 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 
 	x_map = gog_chart_map_get_axis_map (chart_map, 0);
 	y_map = gog_chart_map_get_axis_map (chart_map, 1);
+	z_map = is_map?
+			gog_axis_map_new (model->base.axis[GOG_AXIS_COLOR], 0, 6):
+			NULL;
+	if (is_map)
+		hide_outliers = GOG_XY_COLOR_PLOT (model)->hide_outliers;
 
 	/* Draw drop lines from point to axis start. To change this behaviour
 	 * and draw drop lines from point to zero, we can use gog_axis_map_get_baseline:
@@ -716,6 +979,14 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 			style = gog_style_dup (style);
 		gog_renderer_push_style (view->renderer, style);
 
+		if (is_map) {
+			z_vals = go_data_vector_get_values (
+				GO_DATA_VECTOR (series->base.values[2].data));
+			tmp = go_data_vector_get_len (
+				GO_DATA_VECTOR (series->base.values[2].data));
+			if (n > tmp)
+				n = tmp;
+		}
 		if (GOG_IS_BUBBLE_PLOT (model)) {
 			double zmin;
 			go_data_vector_get_minmax (GO_DATA_VECTOR (series->base.values[2].data), &zmin, &zmax);
@@ -751,7 +1022,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 					gog_axis_map_to_view (y_map, y_vals[i]):
 					go_nan;
 			}
-			switch (style->interpolation.type) {
+			switch (series->base.interpolation) {
 			case GO_LINE_INTERPOLATION_LINEAR: {
 				ArtVpath *path;
 				path = go_line_build_vpath (x_splines, y_splines, n);
@@ -779,7 +1050,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 				if (n == i)
 					break;
 				path = art_new (ArtVpath,
-					((style->interpolation.type <= GO_LINE_INTERPOLATION_STEP_END)?
+					((series->base.interpolation <= GO_LINE_INTERPOLATION_STEP_END)?
 					2 * n + 1: 3 * n + 1));
 				path[0].code = ART_MOVETO;
 				path[0].x = x_splines[i];
@@ -797,7 +1068,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 						path[j].x = x_splines[i];
 						path[j++].y = y_splines[i];
 						b = FALSE;
-					} else switch (style->interpolation.type) {
+					} else switch (series->base.interpolation) {
 					case GO_LINE_INTERPOLATION_STEP_START:
 						path[j].code = ART_LINETO;
 						path[j].x = x_splines[i];
@@ -868,6 +1139,8 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 			y = *y_vals++;
 			if (isnan (y) || isnan (x))
 				continue;
+			if (is_map && isnan (z = *z_vals++))
+				continue;
 			/* We are checking with go_finite here because isinf
 			   if not available everywhere.  Note, that NANs
 			   have been ruled out.  */
@@ -920,6 +1193,10 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 			    y_margin_min <= y_canvas && y_canvas <= y_margin_max) {
 				markers[j][k].x = x_canvas;
 				markers[j][k].y = y_canvas;
+				if (is_map)
+					markers[j][k].color = (gog_axis_map_finite (z_map, z))?
+							get_map_color (gog_axis_map_to_view (z_map, z), hide_outliers):
+							0;
 				k++;
 			}
 		}
@@ -943,10 +1220,20 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 					series = ptr->data;
 					style = GOG_STYLED_OBJECT (series)->style;
 					gog_renderer_push_style (view->renderer, style);
-					for (k = 0; k < num_markers[j]; k++)
+					for (k = 0; k < num_markers[j]; k++) {
+						if (is_map) {
+							go_marker_set_outline_color
+								(style->marker.mark,markers[j][k].color);
+							go_marker_set_fill_color
+								(style->marker.mark,markers[j][k].color);
+							gog_renderer_push_style (view->renderer, style);
+						}
 						gog_renderer_draw_marker (view->renderer, 
 									  markers[j][k].x,
 									  markers[j][k].y);
+						if (is_map)
+							gog_renderer_pop_style (view->renderer);
+					}
 					gog_renderer_pop_style (view->renderer);
 					g_free (markers[j]);
 				}
@@ -957,6 +1244,8 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 		gog_view_render	(ptr->data, bbox);
 
 	gog_chart_map_free (chart_map);
+	if (is_map)
+		gog_axis_map_free (z_map);
 }
 
 static GogViewClass *xy_view_parent_klass;
@@ -1097,7 +1386,7 @@ gog_xy_series_update (GogObject *obj)
 		y_len = go_data_vector_get_len (
 			GO_DATA_VECTOR (series->base.values[1].data));
 	}
-	if (GOG_IS_BUBBLE_PLOT (series->base.plot)) {
+	if (GOG_IS_BUBBLE_PLOT (series->base.plot) || GOG_IS_XY_COLOR_PLOT (series->base.plot)) {
 		double *z_vals = NULL;
 		int z_len = 0;
 		if (series->base.values[2].data != NULL) {
@@ -1162,25 +1451,31 @@ static void
 gog_xy_series_init_style (GogStyledObject *gso, GogStyle *style)
 {
 	GogSeries *series = GOG_SERIES (gso);
-	GogXYPlot const *plot;
 
 	series_parent_klass->init_style (gso, style);
 	if (series->plot == NULL ||
 	    GOG_IS_BUBBLE_PLOT (series->plot))
 		return;
 
-	plot = GOG_XY_PLOT (series->plot);
+	if (GOG_IS_XY_PLOT (series->plot)) {
+		GogXYPlot const *plot = GOG_XY_PLOT (series->plot);
 
-	if (!plot->default_style_has_markers &&
-	    style->marker.auto_shape) 
-		go_marker_set_shape (style->marker.mark, GO_MARKER_NONE);
+		if (!plot->default_style_has_markers &&
+			style->marker.auto_shape)
+			go_marker_set_shape (style->marker.mark, GO_MARKER_NONE);
 
-	if (!plot->default_style_has_lines &&
-	    style->line.auto_dash)
-		style->line.dash_type = GO_LINE_NONE;
+		if (!plot->default_style_has_lines &&
+			style->line.auto_dash)
+			style->line.dash_type = GO_LINE_NONE;
 
-	if (style->interpolation.auto_type)
-		style->interpolation.type = plot->interpolation;
+		if (plot->use_splines)
+			series->interpolation = GO_LINE_INTERPOLATION_SPLINE;
+	} else {
+		GogXYColorPlot const *plot = GOG_XY_COLOR_PLOT (series->plot);
+		if (!plot->default_style_has_lines &&
+			style->line.auto_dash)
+			style->line.dash_type = GO_LINE_NONE;
+	}
 }
 
 static void
@@ -1258,8 +1553,6 @@ gog_xy_series_get_property (GObject *obj, guint param_id,
 }
 
 #ifdef GOFFICE_WITH_GTK
-#include <goffice/gtk/goffice-gtk.h>
-#include <gtk/gtktogglebutton.h>
 static void
 invalid_toggled_cb (GtkToggleButton *btn, GObject *obj)
 {
@@ -1324,6 +1617,7 @@ gog_xy_series_class_init (GogStyledObjectClass *gso_klass)
 	};
 	GogObjectClass *gog_klass = (GogObjectClass *)gso_klass;
 	GObjectClass *gobject_klass = (GObjectClass *) gso_klass;
+	GogSeriesClass *series_klass = (GogSeriesClass *) gso_klass;
 
 	series_parent_klass = g_type_class_peek_parent (gso_klass);
 	gog_klass->update	= gog_xy_series_update;
@@ -1338,21 +1632,28 @@ gog_xy_series_class_init (GogStyledObjectClass *gso_klass)
 	gog_klass->populate_editor	= gog_xy_series_populate_editor;
 #endif
 	gso_klass->init_style		= gog_xy_series_init_style;
+	series_klass->has_interpolation = TRUE;
 
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
 	g_object_class_install_property (gobject_klass, SERIES_PROP_XERRORS,
-		g_param_spec_object ("x-errors", "x-errors",
-			"GogErrorBar *",
-			GOG_ERROR_BAR_TYPE, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_object ("x-errors", 
+			_("X error bars"),
+			_("GogErrorBar *"),
+			GOG_ERROR_BAR_TYPE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_YERRORS,
-		g_param_spec_object ("y-errors", "y-errors",
-			"GogErrorBar *",
-			GOG_ERROR_BAR_TYPE, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_object ("y-errors", 
+			_("Y error bars"),
+			_("GogErrorBar *"),
+			GOG_ERROR_BAR_TYPE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_INVALID_AS_ZERO,
-		g_param_spec_boolean ("invalid-as-zero", _("invalid-as-zero"),
+		g_param_spec_boolean ("invalid-as-zero", 
+			_("Invalid as zero"),
 			_("Replace invalid values by 0 when drawing markers or bubbles"),
-			FALSE, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+			FALSE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
 }
 
 GSF_DYNAMIC_CLASS (GogXYSeries, gog_xy_series,
@@ -1366,6 +1667,7 @@ go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 	gog_2d_plot_register_type (module);
 	gog_xy_plot_register_type (module);
 	gog_bubble_plot_register_type (module);
+	gog_xy_color_plot_register_type (module);
 	gog_xy_view_register_type (module);
 	gog_xy_series_view_register_type (module);
 	gog_xy_series_register_type (module);
