@@ -58,7 +58,7 @@ gog_lin_reg_curve_update (GogObject *obj)
 	nb = gog_series_get_xy_data (series, &x_vals, &y_vals);
 	used = (GOG_LIN_REG_CURVE_GET_CLASS(rc))->build_values (rc, x_vals, y_vals, nb);
 	if (used > 1) {
-		regression_stat_t *stats = go_regression_stat_new ();
+		go_regression_stat_t *stats = go_regression_stat_new ();
 		RegressionResult res =
 			(GOG_LIN_REG_CURVE_GET_CLASS(rc))->lin_reg_func (rc->x_vals, rc->dims,
 						rc->y_vals, used, rc->affine, rc->base.a, stats);
@@ -262,12 +262,17 @@ gog_lin_reg_curve_class_init (GogRegCurveClass *reg_curve_klass)
 	lin_klass->build_values = gog_lin_reg_curve_build_values;
 
 	g_object_class_install_property (gobject_klass, REG_LIN_REG_CURVE_PROP_AFFINE,
-		g_param_spec_boolean ("affine", "affine",
-			"If true, a non-zero constant is allowed",
-			TRUE, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("affine", 
+			_("Affine"),
+			_("If true, a non-zero constant is allowed"),
+			TRUE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, REG_LIN_REG_CURVE_PROP_DIMS,
-		g_param_spec_uint ("dims", "dims",
-			"Number of x-vectors", 1, 10, 1, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_uint ("dims", 
+			_("Dims"),
+			_("Number of x-vectors"),
+		       	1, 10, 1, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
 }
 
 static void
